@@ -1,6 +1,6 @@
 """Modularized losses/procedures for RL algorithms."""
-from .cdq_learning import ClippedDoubleQLearning
-from .cdq_learning import SoftCDQLearning
+from .abstract import Loss
+from .dyna import DynaQLearning
 from .isfv_iteration import ISFittedVIteration
 from .isfv_iteration import ISSoftVIteration
 from .mage import MAGE
@@ -9,13 +9,16 @@ from .mle import MaximumLikelihood
 from .policy_gradient import ActionDPG
 from .policy_gradient import DeterministicPolicyGradient
 from .policy_gradient import ReparameterizedSoftPG
+from .q_learning import FittedQLearning
 from .svg import OneStepSoftSVG
 from .svg import OneStepSVG
 from .svg import TrajectorySVG
 
 
 __all__ = [
-    "ClippedDoubleQLearning",
+    "Loss",
+    "DynaQLearning",
+    "FittedQLearning",
     "ActionDPG",
     "DeterministicPolicyGradient",
     "ISFittedVIteration",
@@ -26,6 +29,5 @@ __all__ = [
     "OneStepSVG",
     "OneStepSoftSVG",
     "ReparameterizedSoftPG",
-    "SoftCDQLearning",
     "TrajectorySVG",
 ]
