@@ -6,8 +6,8 @@ from typing import Tuple
 
 from torch import Tensor
 
-from raylab.utils.annotations import StatDict
-from raylab.utils.annotations import TensorDict
+from raylab.utils.types import StatDict
+from raylab.utils.types import TensorDict
 
 __all__ = [
     "Dict",
